aboutsummaryrefslogtreecommitdiffstats
path: root/sound/usb/line6/pcm.h
diff options
context:
space:
mode:
authorChris Rorvick <chris@rorvick.com>2015-01-20 02:20:49 -0600
committerTakashi Iwai <tiwai@suse.de>2015-01-20 09:52:30 +0100
commitc6fffce92e1a8cda8c1b552f5a24295839f3f93a (patch)
treebd550e912d3cea8916757d8e65e946a33515a0e1 /sound/usb/line6/pcm.h
parentALSA: line6: Remove superfluous NULL checks (diff)
downloadlinux-dev-c6fffce92e1a8cda8c1b552f5a24295839f3f93a.tar.xz
linux-dev-c6fffce92e1a8cda8c1b552f5a24295839f3f93a.zip
ALSA: line6: Refer to manufacturer as "Line 6"
The correct spelling includes the space. Fix this in strings and comments that refer to the manufacturer. Signed-off-by: Chris Rorvick <chris@rorvick.com> Signed-off-by: Takashi Iwai <tiwai@suse.de>
Diffstat (limited to 'sound/usb/line6/pcm.h')
-rw-r--r--sound/usb/line6/pcm.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/sound/usb/line6/pcm.h b/sound/usb/line6/pcm.h
index 9328e6ffb191..715e84b3057c 100644
--- a/sound/usb/line6/pcm.h
+++ b/sound/usb/line6/pcm.h
@@ -1,5 +1,5 @@
/*
* Line6 Linux USB driver - 0.9.1beta
*
* Copyright (C) 2004-2010 Markus Grabner (grabner@icg.tugraz.at)
*
@@ -26,7 +26,7 @@
/*
number of USB frames per URB
- The Line6 Windows driver always transmits two frames per packet, but
+ The Line 6 Windows driver always transmits two frames per packet, but
the Linux driver performs significantly better (i.e., lower latency)
with only one frame per packet.
*/
@@ -38,7 +38,7 @@
#define LINE6_IMPULSE_DEFAULT_PERIOD 100
/*
- Get substream from Line6 PCM data structure
+ Get substream from Line 6 PCM data structure
*/
#define get_substream(line6pcm, stream) \
(line6pcm->pcm->streams[stream].substream)
@@ -46,7 +46,7 @@
/*
PCM mode bits.
- There are several features of the Line6 USB driver which require PCM
+ There are several features of the Line 6 USB driver which require PCM
data to be exchanged with the device:
*) PCM playback and capture via ALSA
*) software monitoring (for devices without hardware monitoring)
@@ -167,7 +167,7 @@ struct line6_pcm_properties {
struct snd_line6_pcm {
/**
- Pointer back to the Line6 driver data structure.
+ Pointer back to the Line 6 driver data structure.
*/
struct usb_line6 *line6;
@@ -1,5 +1,5 @@
/*
- * Line6 Linux USB driver - 0.9.1beta
+ * Line 6 Linux USB driver - 0.9.1beta
*
* Copyright (C) 2004-2010 Markus Grabner (grabner@icg.tugraz.at)